@@ -23,7 +23,7 @@
 
 #include "krununittest.h"
 
-#include <QtTest/QtTest>
+#include <QtTest>
 
 QTEST_GUILESS_MAIN(KRunUnitTest)
 
