@@ -22,8 +22,8 @@
 #ifndef KIO_COPYJOB_H
 #define KIO_COPYJOB_H
 
-#include <QtCore/QObject>
-#include <QtCore/QStringList>
+#include <QObject>
+#include <QStringList>
 #include <QDateTime>
 #include <QUrl>
 
@@ -50,6 +50,8 @@ struct CopyInfo {
 
 class CopyJobPrivate;
 /**
+ * @class KIO::CopyJob copyjob.h <KIO/CopyJob>
+ *
  * CopyJob is used to move, copy or symlink files and directories.
  * Don't create the job directly, but use KIO::copy(),
  * KIO::move(), KIO::link() and friends.
@@ -160,6 +162,7 @@ Q_SIGNALS:
      * @param files a list of items that are about to be created.
      * @deprecated since 5.2 -- this signal is unused since kde 3...
      */
+
     QT_MOC_COMPAT void aboutToCreate(KIO::Job *job, const QList<KIO::CopyInfo> &files);
 
     /**
