@@ -23,7 +23,7 @@
 #ifndef KPROPERTIESDIALOG_H
 #define KPROPERTIESDIALOG_H
 
-#include <QtCore/QString>
+#include <QString>
 #include <QUrl>
 
 #include "kiowidgets_export.h"
@@ -39,6 +39,8 @@ class Job;
 }
 
 /**
+ * @class KPropertiesDialog kpropertiesdialog.h <KPropertiesDialog>
+ *
  * The main properties dialog class.
  * A Properties Dialog is a dialog which displays various information
  * about a particular file or URL, or several files or URLs.
@@ -47,7 +49,7 @@ class Job;
  * The various tabs themselves will let the user view, and sometimes change,
  * information about the file or URL.
  *
- * \image html kpropertiesdialog.png "Typical KProperties Dialog"
+ * \image html kpropertiesdialog.png "Example of KPropertiesDialog"
  *
  * The best way to display the properties dialog is to use showDialog().
  * Otherwise, you should use (void)new KPropertiesDialog(...)
@@ -82,10 +84,9 @@ public:
      *
      * @param item file item whose properties should be displayed.
      * @param parent is the parent of the dialog widget.
-     * @param name is the internal name.
      */
     explicit KPropertiesDialog(const KFileItem &item,
-                               QWidget *parent = 0);
+                               QWidget *parent = nullptr);
 
     /**
      * \overload
@@ -97,10 +98,9 @@ public:
      *
      * @param _items list of file items whose properties should be displayed.
      * @param parent is the parent of the dialog widget.
-     * @param name is the internal name.
      */
     explicit KPropertiesDialog(const KFileItemList &_items,
-                               QWidget *parent = 0);
+                               QWidget *parent = nullptr);
 
     /**
      * Brings up a Properties dialog. Convenience constructor for
@@ -109,13 +109,12 @@ public:
      *
      * @param url the URL whose properties should be displayed
      * @param parent is the parent of the dialog widget.
-     * @param name is the internal name.
      *
      * For local files with a known mimetype, simply create a KFileItem
      * and pass it to the other constructor.
      */
     explicit KPropertiesDialog(const QUrl &url,
-                               QWidget *parent = 0);
+                               QWidget *parent = nullptr);
 
     /**
      * Brings up a Properties dialog. Convenience constructor for
@@ -125,7 +124,6 @@ public:
      * @param urls list of URLs whose properties should be displayed (must
      *             contain at least one non-empty URL)
      * @param parent is the parent of the dialog widget.
-     * @param name is the internal name.
      *
      * For local files with a known mimetype, simply create a KFileItemList
      * and pass it to the other constructor.
@@ -133,7 +131,7 @@ public:
      * @since 5.10
      */
     explicit KPropertiesDialog(const QList<QUrl> &urls,
-                               QWidget *parent = Q_NULLPTR);
+                               QWidget *parent = nullptr);
 
     /**
      * Creates a properties dialog for a new .desktop file (whose name
@@ -145,11 +143,10 @@ public:
      * @param _defaultName something to put in the name field,
      * like mimetype.desktop
      * @param parent is the parent of the dialog widget.
-     * @param name is the internal name.
      */
     KPropertiesDialog(const QUrl &_tempUrl, const QUrl &_currentDir,
                       const QString &_defaultName,
-                      QWidget *parent = 0);
+                      QWidget *parent = nullptr);
 
     /**
      * Creates an empty properties dialog (for applications that want use
@@ -157,11 +154,9 @@ public:
      *
      * @param title is the string display as the "filename" in the caption of the dialog.
      * @param parent is the parent of the dialog widget.
-     * @param name is the internal name.
-     * @param modal tells the dialog whether it should be modal.
      */
     explicit KPropertiesDialog(const QString &title,
-                               QWidget *parent = 0);
+                               QWidget *parent = nullptr);
 
     /**
      * Cleans up the properties dialog and frees any associated resources,
@@ -178,7 +173,7 @@ public:
      *
      * @return true on successful dialog displaying (can be false on win32).
      */
-    static bool showDialog(const KFileItem &item, QWidget *parent = 0,
+    static bool showDialog(const KFileItem &item, QWidget *parent = nullptr,
                            bool modal = true);
 
     /**
@@ -189,7 +184,7 @@ public:
      *
      * @return true on successful dialog displaying (can be false on win32).
      */
-    static bool showDialog(const QUrl &_url, QWidget *parent = 0,
+    static bool showDialog(const QUrl &_url, QWidget *parent = nullptr,
                            bool modal = true);
 
     /**
@@ -201,7 +196,7 @@ public:
      *
      * @return true on successful dialog displaying (can be false on win32).
      */
-    static bool showDialog(const KFileItemList &_items, QWidget *parent = 0,
+    static bool showDialog(const KFileItemList &_items, QWidget *parent = nullptr,
                            bool modal = true);
 
     /**
@@ -221,7 +216,7 @@ public:
      *
      * @since 5.10
      */
-    static bool showDialog(const QList<QUrl> &urls, QWidget *parent = Q_NULLPTR,
+    static bool showDialog(const QList<QUrl> &urls, QWidget *parent = nullptr,
                            bool modal = true);
 
     /**
@@ -341,12 +336,12 @@ public Q_SLOTS:
      * Called when the user presses 'Ok'.
      * @deprecated since 5.25, use accept()
      */
-    KIOWIDGETS_DEPRECATED virtual void slotOk() { accept(); }
+    KIOWIDGETS_DEPRECATED virtual void slotOk();
     /**
      * Called when the user presses 'Cancel'.
      * @deprecated since 5.25, use reject()
      */
-    KIOWIDGETS_DEPRECATED virtual void slotCancel() { reject(); }
+    KIOWIDGETS_DEPRECATED virtual void slotCancel();
 
     /**
      * Called when the user presses 'Ok'.
@@ -403,7 +398,7 @@ private:
  *
  * To make a plugin available, define a service that implements the KPropertiesDialog/Plugin
  * servicetype, as well as the mimetypes for which the plugin should be created.
- * For instance, ServiceTypes=KPropertiesDialog/Plugin,text/html,application/x-mymimetype.
+ * For instance, X-KDE-ServiceTypes=KPropertiesDialog/Plugin,text/html,application/x-mymimetype.
  *
  * You can also include X-KDE-Protocol=file if you want that plugin
  * to be loaded only for local files, for instance.
